@@ -69,11 +69,6 @@ struct _BjbMainToolbar
   GtkWidget *main_button;
   GtkWidget *menu_button;
 
-  /* Main menu items */
-  GtkWidget *large_item;
-  GtkWidget *medium_item;
-  GtkWidget *small_item;
-
   /* Menu items */
   GtkWidget *new_window_item;
   GtkWidget *undo_item;
@@ -107,70 +102,6 @@ static GParamSpec *properties[NUM_PROPERTIES] = { NULL, };
 
 G_DEFINE_TYPE (BjbMainToolbar, bjb_main_toolbar, GTK_TYPE_HEADER_BAR)
 
-static void
-on_about_cb (BjbMainToolbar *self)
-{
-  bjb_app_about (BJB_APPLICATION (g_application_get_default ()));
-}
-
-static void
-on_import_notes_cb (BjbMainToolbar *self)
-{
-  bjb_app_import_notes (BJB_APPLICATION (g_application_get_default ()));
-}
-
-static void
-on_view_trash_cb (BjbMainToolbar *self)
-{
-  GtkApplication *app = GTK_APPLICATION (g_application_get_default ());
-  GList *windows = gtk_application_get_windows (app);
-  BjbController *controller = bjb_window_base_get_controller (BJB_WINDOW_BASE (windows->data));
-
-  bjb_controller_set_group (controller, BIJI_ARCHIVED_ITEMS);
-}
-
-static void
-on_text_size_cb (BjbMainToolbar *self,
-                 GtkWidget      *item)
-{
-  BjbSettings *settings = bjb_app_get_settings (g_application_get_default ());
-  BjbTextSizeType text_size = g_settings_get_enum (G_SETTINGS (settings), "text-size");
-  BjbTextSizeType new_text_size = text_size;
-
-  if (item == self->large_item)
-    {
-      new_text_size = BJB_TEXT_SIZE_LARGE;
-    }
-  else if (item == self->medium_item)
-    {
-      new_text_size = BJB_TEXT_SIZE_MEDIUM;
-    }
-  else if (item == self->small_item)
-    {
-      new_text_size = BJB_TEXT_SIZE_SMALL;
-    }
-
-  if (text_size != new_text_size)
-    {
-      g_settings_set_enum (G_SETTINGS (settings), "text-size", new_text_size);
-    }
-}
-
-static void
-on_preferences_cb (BjbMainToolbar *self)
-{
-  GtkApplication *app = GTK_APPLICATION (g_application_get_default ());
-  GList *windows = gtk_application_get_windows (app);
-
-  show_bijiben_settings_window (g_list_nth_data (windows, 0));
-}
-
-static void
-on_help_cb (BjbMainToolbar *self)
-{
-  bjb_app_help (BJB_APPLICATION (g_application_get_default ()));
-}
-
 static void
 on_new_note_clicked (BjbMainToolbar *self)
 {
@@ -497,74 +428,7 @@ on_last_updated_cb (BijiItem       *note,
    */
   label = g_strdup_printf (_("Last updated %s"),
                            biji_note_obj_get_last_change_date_string (self->note));
-  gtk_menu_item_set_label (GTK_MENU_ITEM (self->last_update_item), label);
-}
-
-static void
-action_view_tags_callback (BjbMainToolbar *self)
-{
-  GList *list = NULL;
-
-  g_assert (BJB_IS_MAIN_TOOLBAR (self));
-
-  list = g_list_append (list, self->note);
-  bjb_organize_dialog_new (self->window, list);
-  g_list_free (list);
-}
-
-static void
-trash_item_callback (BjbMainToolbar *self)
-{
-  g_assert (BJB_IS_MAIN_TOOLBAR (self));
-
-  if (!self->note)
-    return;
-
-  /* Delete the note from notebook
-   * The deleted note will emit a signal. */
-  biji_item_trash (BIJI_ITEM (self->note));
-}
-
-static void
-on_undo_or_redo_cb (BjbMainToolbar *self,
-                    GtkWidget      *menu_item)
-{
-  BijiWebkitEditor *editor;
-
-  g_assert (BJB_IS_MAIN_TOOLBAR (self));
-  g_assert (GTK_IS_MENU_ITEM (menu_item));
-
-  if (!self->note)
-    return;
-
-  editor = BIJI_WEBKIT_EDITOR (biji_note_obj_get_editor (self->note));
-
-  if (menu_item == self->undo_item)
-    biji_webkit_editor_undo (editor);
-  else
-    biji_webkit_editor_redo (editor);
-}
-
-static void
-on_detached_clicked_cb (BjbMainToolbar *self)
-{
-  BijiNoteObj *note;
-
-  g_assert (BJB_IS_MAIN_TOOLBAR (self));
-
-  note = bjb_window_base_get_note (BJB_WINDOW_BASE (self->window));
-  bjb_window_base_switch_to (BJB_WINDOW_BASE (self->window),
-                             BJB_WINDOW_BASE_MAIN_VIEW);
-  bijiben_new_window_for_note (g_application_get_default (), note);
-}
-
-static void
-on_email_cb (BjbMainToolbar *self,
-             GtkWidget      *menu_item)
-{
-  g_return_if_fail (self->note);
-
-  on_email_note_callback (self->note);
+  gtk_label_set_text (GTK_LABEL (self->last_update_item), label);
 }
 
 static void
@@ -781,9 +645,6 @@ populate_main_toolbar(BjbMainToolbar *self)
 static void
 bjb_main_toolbar_setup_menu (BjbMainToolbar *self)
 {
-  BjbSettings *settings = bjb_app_get_settings (g_application_get_default ());
-  BjbTextSizeType text_size = g_settings_get_enum (G_SETTINGS (settings), "text-size");
-
   gtk_widget_add_accelerator (self->undo_item, "activate", self->accel, GDK_KEY_z,
                               GDK_CONTROL_MASK, GTK_ACCEL_VISIBLE);
   gtk_widget_add_accelerator (self->redo_item, "activate", self->accel, GDK_KEY_z,
@@ -791,11 +652,6 @@ bjb_main_toolbar_setup_menu (BjbMainToolbar *self)
   gtk_widget_add_accelerator (self->trash_item, "activate", self->accel,
                               GDK_KEY_Delete, GDK_CONTROL_MASK,
                               GTK_ACCEL_VISIBLE);
-
-  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (self->large_item), text_size == BJB_TEXT_SIZE_LARGE);
-  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (self->medium_item), text_size == BJB_TEXT_SIZE_MEDIUM);
-  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (self->small_item), text_size == BJB_TEXT_SIZE_SMALL);
-
 }
 
 static void
@@ -934,11 +790,6 @@ bjb_main_toolbar_class_init (BjbMainToolbarClass *klass)
   gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, main_button);
   gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, menu_button);
 
-  /* Main menu items */
-  gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, large_item);
-  gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, medium_item);
-  gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, small_item);
-
   /* Menu items */
   gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, new_window_item);
   gtk_widget_class_bind_template_child (widget_class, BjbMainToolbar, undo_item);
@@ -952,21 +803,6 @@ bjb_main_toolbar_class_init (BjbMainToolbarClass *klass)
   gtk_widget_class_bind_template_callback (widget_class, on_view_mode_clicked);
   gtk_widget_class_bind_template_callback (widget_class, on_empty_clicked_callback);
   gtk_widget_class_bind_template_callback (widget_class, on_color_button_clicked);
-
-  /* Main menu items */
-  gtk_widget_class_bind_template_callback (widget_class, on_import_notes_cb);
-  gtk_widget_class_bind_template_callback (widget_class, on_view_trash_cb);
-  gtk_widget_class_bind_template_callback (widget_class, on_preferences_cb);
-  gtk_widget_class_bind_template_callback (widget_class, on_help_cb);
-  gtk_widget_class_bind_template_callback (widget_class, on_about_cb);
-  gtk_widget_class_bind_template_callback (widget_class, on_text_size_cb);
-
-  /* Menu items */
-  gtk_widget_class_bind_template_callback (widget_class, on_detached_clicked_cb);
-  gtk_widget_class_bind_template_callback (widget_class, on_undo_or_redo_cb);
-  gtk_widget_class_bind_template_callback (widget_class, action_view_tags_callback);
-  gtk_widget_class_bind_template_callback (widget_class, trash_item_callback);
-  gtk_widget_class_bind_template_callback (widget_class, on_email_cb);
 }
 
 BjbMainToolbar *
